@@ -19,14 +19,30 @@
 #ifndef HISTORY_H
 #define HISTORY_H
 
+G_BEGIN_DECLS
+
+/* Defines */
+#define HISTFILE ".local/share/parcellite/history"
+
 /* External variables */
 extern GSList* history;
 
 /* Functions */
-void h_read();
-void h_save();
-void h_append(gchar* item);
-void h_truncate();
-gpointer h_get_last();
+void
+read_history();
+
+void
+save_history();
+
+void
+append_item(gchar* item);
+
+void
+truncate_history();
+
+gpointer
+get_last_item();
+
+G_END_DECLS
 
 #endif
