@@ -16,21 +16,42 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "preferences.h"
+
 #ifndef MAIN_H
 #define MAIN_H
 
-/* External variables */
-extern gint history_limit;
-extern gint character_length;
-extern gint ellipsize;
-extern gchar* history_key;
-extern gchar* actions_key;
-extern gboolean save_history;
-extern gboolean single_line_mode;
-extern gboolean hyperlinks_mode;
+G_BEGIN_DECLS
+
+/* Defines */
+#define POPUPDELAY    100
+#define PRIMARYDELAY  500
+
+/* Typedefs */
+typedef struct
+{
+  gint      histlim;     /* History items */
+  gint      charlength;  /* Character length of items */
+  gint      ellipsize;   /* Omit long items */
+  gchar*    histkey;     /* History menu hotkey */
+  gchar*    actionkey;   /* Actions menu hotkey */
+  gboolean  savehist;    /* Save history */
+  gboolean  revhist;     /* Reverse history */
+  gboolean  singleline;  /* Single line mode */
+  gboolean  hyperlinks;  /* Hyperlinks only */
+  gboolean  noicon;      /* No icon */
+}
+prefs_t;
+
+extern prefs_t prefs;
 
 /* Functions */
-void bind_keys();
-void unbind_keys();
+void
+on_history_hotkey(char *keystring, gpointer user_data);
+
+void
+on_actions_hotkey(char *keystring, gpointer user_data);
+
+G_END_DECLS
 
 #endif
