@@ -19,8 +19,31 @@
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
 
+G_BEGIN_DECLS
+
+/* Defines: default preferences */
+#define DEFELLIPSIZE       2
+#define DEFHISTORYLIM      25
+#define DEFCHARLENGTH      50
+#define DEFACTIONSKEY      "<Ctrl><Alt>A"
+#define DEFHISTORYKEY      "<Ctrl><Alt>H"
+#define DEFSAVELIST        TRUE
+#define DEFREVHISTORY      FALSE
+#define DEFSINGLELINEMODE  TRUE
+#define DEFHYPERLINKSMODE  FALSE
+#define DEFNOICON          FALSE
+
+/* Defines: others */
+#define ACTIONSFILE  ".local/share/parcellite/actions"
+#define PREFFILE     ".config/parcellite/parcelliterc"
+
 /* Functions */
-void p_read();
-void p_show_dialog(gint tab);
+void
+read_preferences();
+
+void
+show_preferences(gint tab);
+
+G_END_DECLS
 
 #endif
