@@ -19,9 +19,22 @@
 #ifndef UTILS_H
 #define UTILS_H
 
+G_BEGIN_DECLS
+
+/* Defines */
+#define PARCCONFIGDIR  ".local/share/parcellite"
+#define PARCDATADIR    ".config/parcellite"
+
 /* Functions */
-void u_check_directories();
-gboolean u_check_hyperlink(gchar* link);
-gboolean u_parse_options(int argc, char* argv[]);
+void
+check_dirs();
+
+gboolean
+is_hyperlink(gchar* link);
+
+gboolean
+parse_options(int argc, char* argv[]);
+
+G_END_DECLS
 
 #endif
